EventTracingWindowsPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • EventTracingWindowsPlatform
Implementers

Constructors

EventTracingWindowsPlatform()
Constructs a EventTracingWindowsPlatform.

Properties

fileEventStream → Stream<FileEvent>
获取文件事件流
no setter
hashCode → int
The hash code for this object.
no setterinherited
processEventStream → Stream<ProcessEvent>
获取进程事件流
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPlatformVersion() → Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startFileMonitoring() → Future<bool>
开始监听文件系统事件 需要管理员权限
startProcessMonitoring() → Future<bool>
开始监听进程事件 需要管理员权限
stopFileMonitoring() → Future<bool>
停止监听文件系统事件
stopProcessMonitoring() → Future<bool>
停止监听进程事件
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ EventTracingWindowsPlatform
The default instance of EventTracingWindowsPlatform to use.
getter/setter pair